@@ -6,11 +6,11 @@ import (
 	"strings"
 
 	"github.com/Azure/azure-sdk-for-go/sdk/azcore"
-	"github.com/Azure/azure-sdk-for-go/sdk/keyvault/azsecrets"
+	"github.com/Azure/azure-sdk-for-go/sdk/azidentity"
+	"github.com/Azure/azure-sdk-for-go/sdk/security/keyvault/azsecrets"
 	"gopkg.in/yaml.v3"
 
 	"github.com/helmfile/vals/pkg/api"
-	"github.com/helmfile/vals/pkg/azureclicompat"
 )
 
 type provider struct {
@@ -66,12 +66,16 @@ func (p *provider) getClientForKeyVault(vaultBaseURL string) (*azsecrets.Client,
 		return nil, err
 	}
 
-	p.clients[vaultBaseURL] = azsecrets.NewClient(vaultBaseURL, cred, nil)
+	p.clients[vaultBaseURL], err = azsecrets.NewClient(vaultBaseURL, cred, nil)
+	if err != nil {
+		return nil, err
+	}
+
 	return p.clients[vaultBaseURL], nil
 }
 
 func getTokenCredential() (azcore.TokenCredential, error) {
-	cred, err := azureclicompat.ResolveIdentity()
+	cred, err := azidentity.NewDefaultAzureCredential(nil)
 	if err != nil {
 		return nil, err
 	}
